@@ -9,7 +9,7 @@ use Pod::Abstract::BuildNode qw(node nodes);
 
 
 use vars qw($VERSION);
-$VERSION = '1.04';
+$VERSION = '1.05';
 
 # This Module is designed to generate pod documentation of a perl class by analysing its code.
 # The idea is to have something similar like javadoc. So it uses also comments written directly
@@ -34,6 +34,7 @@ $VERSION = '1.04';
 #
 #  # reading and Foo.pm and prints the generated pod. 
 #
+#  use Pod::Autopod;
 #
 #  my $ap = new Pod::Autopod();
 #  $ap->setPerlCode($mycode);
@@ -76,8 +77,9 @@ $VERSION = '1.04';
 #
 #  $this->foo($text);
 #
-# The object "$this" is the default and automatially used when a constructor was found ("new"). You
-# can change this by the parameter "selfstring" in the autoperl constructor.
+# The object "$this" is the default and automatially used when a constructor was found ("new")
+# or the class inherits with ISA or "use base".
+# You can change this by the parameter "selfstring" in the autopod constructor.
 #
 # The example looks simple, but the engine does more than you think. Please have a look here:
 #
@@ -361,7 +363,7 @@ my $arr=shift or die "Arrayref expected";
 		}
 
 
-		if ((($line=~ m/^\s*\}/) || ($p == 0)) && ($this->{'STATE'}=~ m/^(head|headwait|bodywait|free)$/)){ ## last line of body
+		if ((($line=~ m/^\s*\}/) || ($p == 0) || ($line=~ m/^\s*sub [^ ]+/)) && ($this->{'STATE'}=~ m/^(head|headwait|bodywait|free)$/)){ ## last line of body
 			$this->_clearBodyBuffer();
 			$this->{'STATE'} = 'body';
 			$this->_addHeadBufferToAttr();
@@ -397,12 +399,26 @@ my $arr=shift or die "Arrayref expected";
 			$rem=~ s/^[^\#]*\#*//;
 			push @{$this->{'REQUIRES'}},{'name'=>$name,'desc'=>$rem};
 		}
+
+
+		if (($line=~ m/^\s*use base +([^\; ]+)[\;](.*)/) ||
+			($line=~ m/^\s*our +\@ISA +([^\; ]+)[\;](.*)/)){
+			$this->{'INHERITS_FROM'} = $this->{'INHERITS_FROM'} || [];
+			my $name=$1;
+			my $rem=$2;
+			$name=~ s/qw\(//g;
+			$name=~ s/[\)\']//g;
+			my @n=split(/ +/,$name);
+			foreach my $n (@n){
+				push @{$this->{'INHERITS_FROM'}},{'name'=>$n} if $n;	
+			}
+		}
 		
 		#print $line.'   -   '.$this->{'STATE'};
 	}
 	
 	
-	if (exists $this->{'METHOD_ATTR'}->{'new'}){ ## its a class!
+	if ((exists $this->{'METHOD_ATTR'}->{'new'}) || (scalar($this->{'INHERITS_FROM'}) >= 1 )){ ## its a class!
 		$this->{'ISCLASS'}=1;
 	}
 	
@@ -855,6 +871,7 @@ my $attr = $this->{'METHOD_ATTR'};
 	$this->_buildPod_Name();
 	$this->_buildPod_Methods();
 	$this->_buildPod_Requires();
+	$this->_buildPod_Inherits();
 	$this->_buildPod_More();
 
 
@@ -873,7 +890,7 @@ my $this=shift;
 
 
 	my %dontshow;
-	my @dontshow = qw(vars strict warnings libs);
+	my @dontshow = qw(vars strict warnings libs base);
 	map {$dontshow{$_}=1} @dontshow;
 
 	my $node = node->root;
@@ -899,11 +916,45 @@ my $this=shift;
 		
 		$this->{'POD_PARTS'}->{'REQUIRES'} = $node;	
 	}
+
+}
+
+
+
+
+
+sub _buildPod_Inherits{
+my $this=shift;
+
+	my $re=$this->{'INHERITS_FROM'} || [];
+
+	my %dontshow;
+	my @dontshow = qw(vars strict warnings libs base);
+	map {$dontshow{$_}=1} @dontshow;
+
+	my $node = node->root;
+
+	$node->push( node->head1("IMPLEMENTS") );
 	
+	if (scalar(@$re) > 0){
 
 
+		foreach my $e (@$re){
 
+			my $name=$e->{'name'};
+			my $desc=$e->{'desc'};
 
+			if (!$dontshow{$name}){
+
+				$desc=$this->_trim($desc);
+				my $text = "L<$name> $desc\n\n";
+
+				$node->push( node->text($text));
+			}		
+		}
+		
+		$this->{'POD_PARTS'}->{'IMPLEMENTS'} = $node;	
+	}
 
 }
 
@@ -917,7 +968,7 @@ my $this=shift;
 
 	my @text;
 
-	my @first = qw(NAME SYNOPSIS DESCRIPTION REQUIRES EXPORTS HOWTO NOTES METHODS);
+	my @first = qw(NAME SYNOPSIS DESCRIPTION REQUIRES IMPLEMENTS EXPORTS HOWTO NOTES METHODS);
 	my @last  = ('CAVEATS','TODO','TODOS','SEE ALSO','AUTHOR','COPYRIGHT','LICENSE','COPYRIGHT AND LICENSE');
 
 	my @own = keys %{$parts};
@@ -1189,6 +1240,7 @@ return $c;
 
 
 
+
 #################### pod generated by Pod::Autopod - keep this line to make pod updates possible ####################
 
 =head1 NAME
@@ -1387,6 +1439,13 @@ ConstructorThe keyvalues are not mandatory.selfstring may hold something like '$
 Builds the pod. Called automatically when imporing a perl code.
 
 
+=head2 foo
+
+ $this->foo();
+
+This method is doing foo. print $this->foo();It is not doing bar, only foo.
+
+
 =head2 getPerlCode
 
  my $text = $this->getPerlCode();
